@@ -1,12 +1,13 @@
 import typing
-import pydomainextractor.extractor
+
+from . import extractor
 
 
 class DomainExtractor:
     '''
     PyDomainExtractor is a highly optimized Domain Name Extraction library written in C++
     '''
-    engine: typing.Optional[pydomainextractor.extractor.DomainExtractor] = None
+    engine: typing.Optional[extractor.DomainExtractor] = None
 
     def __new__(
         cls,
@@ -14,8 +15,8 @@ class DomainExtractor:
     ):
         if suffix_list_data is None:
             if DomainExtractor.engine is None:
-                DomainExtractor.engine = pydomainextractor.extractor.DomainExtractor()
+                DomainExtractor.engine = extractor.DomainExtractor()
 
             return DomainExtractor.engine
         else:
-            return pydomainextractor.extractor.DomainExtractor(suffix_list_data)
+            return extractor.DomainExtractor(suffix_list_data)
